@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.0801';
+our $VERSION = '0.09';
 
 use Moo;
 use strictures 2;
@@ -13,9 +13,11 @@ use Lingua::EN::Opinion::Positive;
 use Lingua::EN::Opinion::Negative;
 use Lingua::EN::Opinion::Emotion;
 
+use Carp;
 use File::Slurper qw( read_text );
 use Lingua::EN::Sentence qw( get_sentences );
 use Statistics::Lite qw( mean );
+use Try::Tiny;
 
 
 has file => (
@@ -29,6 +31,33 @@ has text => (
 );
 
 
+has stem => (
+    is      => 'ro',
+    default => sub { 0 },
+);
+
+
+has stemmer => (
+    is       => 'ro',
+    lazy     => 1,
+    builder  => 1,
+    init_arg => undef,
+);
+
+sub _build_stemmer {
+    try {
+        require WordNet::QueryData;
+        require WordNet::stem;
+        my $wn      = WordNet::QueryData->new();
+        my $stemmer = WordNet::stem->new($wn);
+        return $stemmer;
+    }
+    catch {
+        croak 'The WordNet::QueryData and WordNet::stem modules must be installed and working to enable stemming support';
+    };
+}
+
+
 has sentences => (
     is       => 'rw',
     init_arg => undef,
@@ -72,6 +101,8 @@ sub analyze {
         my $score = 0;
 
         for my $word ( @words ) {
+            $word = $self->_stemword($word);
+
             $score += exists $positive->wordlist->{$word} ? 1
                     : exists $negative->wordlist->{$word} ? -1 : 0;
         }
@@ -123,6 +154,8 @@ sub nrc_sentiment {
         my $score;
 
         for my $word ( @words ) {
+            $word = $self->_stemword($word);
+
             if ( exists $emotion->wordlist->{$word} ) {
                 for my $key ( keys %{ $emotion->wordlist->{$word} } ) {
                     $score->{$key} += $emotion->wordlist->{$word}{$key};
@@ -143,6 +176,8 @@ sub nrc_sentiment {
 sub get_word {
     my ( $self, $word ) = @_;
 
+    $word = $self->_stemword($word);
+
     my $positive = Lingua::EN::Opinion::Positive->new();
     my $negative = Lingua::EN::Opinion::Negative->new();
 
@@ -158,6 +193,8 @@ sub get_word {
 sub nrc_get_word {
     my ( $self, $word ) = @_;
 
+    $word = $self->_stemword($word);
+
     my $emotion = Lingua::EN::Opinion::Emotion->new();
 
     return exists $emotion->wordlist->{$word}
@@ -172,7 +209,11 @@ sub get_sentence {
     my @words = _tokenize($sentence);
 
     my %score;
-    $score{$_} = $self->get_word($_) for @words;
+
+    for my $word ( @words ) {
+        $word = $self->_stemword($word);
+        $score{$word} = $self->get_word($word);
+    }
 
     return \%score;
 }
@@ -184,7 +225,11 @@ sub nrc_get_sentence {
     my @words = _tokenize($sentence);
 
     my %score;
-    $score{$_} = $self->nrc_get_word($_) for @words;
+
+    for my $word ( @words ) {
+        $word = $self->_stemword($word);
+        $score{$word} = $self->nrc_get_word($word);
+    }
 
     return \%score;
 }
@@ -196,6 +241,18 @@ sub _tokenize {
     return @words;
 }
 
+sub _stemword {
+    my ( $self, $word ) = @_;
+
+    if ( $self->stem ) {
+        my @stems = $self->stemmer->stemWord($word);
+        $word = [ sort @stems ]->[0]
+            if @stems;
+    }
+
+    return $word;
+}
+
 1;
 
 __END__
@@ -210,12 +267,12 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.0801
+version 0.09
 
 =head1 SYNOPSIS
 
   use Lingua::EN::Opinion;
-  my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt' );
+  my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt', stem => 1 );
   $opinion->analyze();
   my $score = $opinion->averaged_score(5);
   my $sentiment = $opinion->get_word('foo');
@@ -248,6 +305,17 @@ The text file to analyze.
 
 A text string to analyze instead of a text file.
 
+=head2 stem
+
+Boolean flag to indicate that word stemming should take place.
+
+=head2 stemmer
+
+Require the L<WordNet::QueryData> and L<WordNet::stem> modules to stem each word
+of the provided file or text.
+
+* These modules must be installed and working to use this feature.
+
 =head2 sentences
 
 Computed result.
